@@ -153,6 +153,8 @@ class VoiceOutputChannel(OutputChannel):
     async def send_start_marker(self, recipient_id: str) -> None:
         """Send a marker message before the first audio chunk."""
         # Default implementation uses the generic marker message
+        call_state.is_bot_speaking = True  # type: ignore[attr-defined]
+        VoiceInputChannel._cancel_silence_timeout_watcher()
         await self.send_marker_message(recipient_id)
 
     async def send_intermediate_marker(self, recipient_id: str) -> None:
