@@ -35,6 +35,7 @@ from rasa.constants import (
     ENV_LOG_LEVEL_KAFKA,
     ENV_LOG_LEVEL_LIBRARIES,
     ENV_LOG_LEVEL_MATPLOTLIB,
+    ENV_LOG_LEVEL_PYMONGO,
     ENV_LOG_LEVEL_RABBITMQ,
 )
 from rasa.shared.constants import DEFAULT_LOG_LEVEL, ENV_LOG_LEVEL, TCP_PROTOCOL
@@ -247,6 +248,7 @@ def configure_library_logging() -> None:
     update_rabbitmq_log_level(library_log_level)
     update_presidio_log_level(library_log_level)
     update_faker_log_level(library_log_level)
+    update_pymongo_log_level(library_log_level)
 
 
 def update_apscheduler_log_level() -> None:
@@ -394,6 +396,13 @@ def update_faker_log_level(library_log_level: Text) -> None:
     logging.getLogger("faker").propagate = False
 
 
+def update_pymongo_log_level(library_log_level: str) -> None:
+    """Set the log level of pymongo."""
+    log_level = os.environ.get(ENV_LOG_LEVEL_PYMONGO, library_log_level)
+    logging.getLogger("pymongo").setLevel(log_level)
+    logging.getLogger("pymongo").propagate = False
+
+
 def sort_list_of_dicts_by_first_key(dicts: List[Dict]) -> List[Dict]:
     """Sorts a list of dictionaries by their first key."""
     return sorted(dicts, key=lambda d: next(iter(d.keys())))
